#!/usr/bin/python3

#------------------------------------------------------------------------------
# Programa - central_alagamento.py
# Recebe pacote UDP dos sensores de alagamento
# 
# Desenvolvido por: Eng. Márcio José Soares
# versão 1.0 - 02/02/2022
#
# Python 3.8.10
#------------------------------------------------------------------------------

#------------------------------------------------------------------------------
# Libs incluidas
#------------------------------------------------------------------------------
import socket
from threading import Thread
from time import sleep
import sys
import struct
import re

exit = False
state = 0
rec = 0

#------------------------------------------------------------------------------
# Função para receber umdado - bind UDP 
#
# Entradas - número da porta
# Saidas   - nenhuma
#------------------------------------------------------------------------------
def rxThread(portNumR):
    global exit
    global state
    
    #Cria o socket UDP
    rxSocket = socket.socket(socket.AF_INET, #Internet
                             socket.SOCK_DGRAM) #UDP
    
    #Faz o Bind em qualquer porta disponível *portNum*
    rxSocket.bind(("",portNumR))
    
    #Previne o bloqueio do socket até receber um dado
    # Observação: em vez de bloquear, ele lançará uma exceção socket.error se
    # não obtém nenhum dado 
    
    rxSocket.setblocking(0)
    
    while not exit:
        try:
            #Tenta receber até 1024 bytes de dados
            data,addr = rxSocket.recvfrom(1024) 
            #Envia eco dos dados de volta a quem enviou
            #rxSocket.sendto(data,addr)
            #if str(data.decode('utf-8')).find("Alagamento ") == -1: #verifica se dado é real
            print ("\033[1;31;40mRecebendo dado de ",addr)
            print ("\033[1;31;40mRX: " + (data.decode('utf-8'))+"\n")
                
        except socket.error:
            #Se nenhum dado for recebido, você chega aqui, mas não é um erro
            #Ignore e continue 
            pass
    
            sleep(.1)
            
#------------------------------------------------------------------------------
# Função para montar thread de envio
#
# Entradas - nenhuma
# Saídas   - nenhuma
#------------------------------------------------------------------------------
def txThread(portNumT):
    global exit
    
#------------------------------------------------------------------------------
# Função main
#
# Entradas - argumentos
# Saídas   - nenhuma
#------------------------------------------------------------------------------    
def main(args):    
    global exit
    global state
    
    print(chr(27)+'[2j')
    print('\033c')
    print('\x1bc')
    print ("\033[1;32;40mAplicação exemplo Central Alagamento")
    print ("Recebe dados dos sensores de alagamento e mostra na tela") 
    print ("Desenvolvido por: Eng. Márcio José Soares") 
    
    portNumR = 2400
    portNumT = 2390
    
    
    udpRxThreadHandle = Thread(target=rxThread,args=(portNumR,))    
    udpRxThreadHandle.start()
        
    sleep(.1)
    
    #Gera um socket object de transmissão
    txSocket = socket.socket(socket.AF_INET,socket.SOCK_DGRAM)
    
    # Não bloqueie ao procurar dados recebidos (veja a nota acima) 
    txSocket.setblocking(0) 
   
    while True:
        try:
            print ("\n\033[1;34;40mAguardando mensagens\nTecle Ctrl+C para sair!\n")
            
            while True:
                #Dorme para permitir que a thread RX processe os dados
                sleep(.2)
            
        except socket.error as msg:    
            #Se nenhum dado for recebido, você acaba aqui, mas pode ignorar
            # o erro e continuar
            pass   
        except KeyboardInterrupt:
            exit = True
            print ("\033[1;32;40m\nRecebido Ctrl+C... saindo!")
            
            break
        sleep(.1)
         
    udpRxThreadHandle.join()
        
    return

#------------------------------------------------------------------------------
# Fim
if __name__=="__main__":
    main(sys.argv[1:0])     
